@@ -1,13 +1,19 @@
 #line 1 "inc/Module/Install/Can.pm - lib/Module/Install/Can.pm"
 package Module::Install::Can;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.01';
+
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
+$VERSION = '0.57';
 
 use strict;
 use Config ();
-use File::Spec ();
 use ExtUtils::MakeMaker ();
 
+# This may introduce a 5.005 dependency, or at the very least it may
+# not bootstrap properly under 5.004.
+use File::Spec ();
+ 
 # check if we can load some module
 sub can_use {
     my ($self, $mod, $ver) = @_;
@@ -53,7 +59,7 @@ sub can_cc {
 if ($^O eq 'cygwin') {
     require ExtUtils::MM_Cygwin;
     require ExtUtils::MM_Win32;
-    if (!defined(&ExtUtils::MM_Cygwin::maybe_command)) {
+    if ( ! defined(&ExtUtils::MM_Cygwin::maybe_command) ) {
         *ExtUtils::MM_Cygwin::maybe_command = sub {
             my ($self, $file) = @_;
             if ($file =~ m{^/cygdrive/}i and ExtUtils::MM_Win32->can('maybe_command')) {
