@@ -1,14 +1,12 @@
 #line 1 "inc/Module/Install/Metadata.pm - lib/Module/Install/Metadata.pm"
 package Module::Install::Metadata;
 
-use strict 'vars';
 use Module::Install::Base;
+@ISA = qw{Module::Install::Base};
 
-use vars qw($VERSION @ISA);
-BEGIN {
-    $VERSION = '0.06';
-    @ISA     = 'Module::Install::Base';
-}
+$VERSION = '0.57';
+
+use strict 'vars';
 
 my @scalar_keys = qw{
     name module_name abstract author version license
@@ -62,6 +60,16 @@ sub sign {
     return $self;
 }
 
+sub dynamic_config {
+	my $self = shift;
+	unless ( @_ ) {
+		warn "You MUST provide an explicit true/false value to dynamic_config, skipping\n";
+		return $self;
+	}
+	$self->{'values'}{'dynamic_config'} = $_[0] ? 1 : 0;
+	return $self;
+}
+
 sub all_from {
     my ( $self, $file ) = @_;
 
@@ -130,8 +138,7 @@ sub feature {
         # The user used ->feature like ->features by passing in the second
         # argument as a reference.  Accomodate for that.
         $mods = $_[0];
-    }
-    else {
+    } else {
         $mods = \@_;
     }
 
