@@ -1,5 +1,11 @@
 package Module::Install::AutoInstall;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use Module::Install::Base;
+@ISA = qw{Module::Install::Base};
+
+$VERSION = '0.57';
+
+use strict;
 
 sub AutoInstall { $_[0] }
 
