@@ -1,11 +1,16 @@
 package Module::Install::Base;
 
+$VERSION = '0.57';
+
 # Suspend handler for "redefined" warnings
 BEGIN {
 	my $w = $SIG{__WARN__};
 	$SIG{__WARN__} = sub { $w };
 }
 
+### This is the ONLY module that shouldn't have strict on
+# use strict;
+
 =pod
 
 =head1 NAME
@@ -38,13 +43,13 @@ Constructor -- need to preserve at least _top
 sub new {
     my ($class, %args) = @_;
 
-    foreach my $method (qw(call load)) {
+    foreach my $method ( qw(call load) ) {
         *{"$class\::$method"} = sub {
-            +shift->_top->$method(@_);
+            shift()->_top->$method(@_);
         } unless defined &{"$class\::$method"};
     }
 
-    bless(\%args, $class);
+    bless( \%args, $class );
 }
 
 =pod
@@ -57,7 +62,6 @@ The main dispatcher - copy extensions if missing
 
 sub AUTOLOAD {
     my $self = shift;
-
     local $@;
     my $autoload = eval { $self->_top->autoload } or return;
     goto &$autoload;
