@@ -1,7 +1,9 @@
 package Module::Install::MakeMaker;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.01';
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
+$VERSION = '0.57';
 
 use ExtUtils::MakeMaker ();
 
