@@ -1,16 +1,18 @@
 package Module::Install::Makefile;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
 
 use strict 'vars';
-use vars '$VERSION';
-
+use Module::Install::Base;
 use ExtUtils::MakeMaker ();
 
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '0.57';
+	@ISA     = qw{Module::Install::Base};
+}
+
 sub Makefile { $_[0] }
 
-sub prompt { 
+sub prompt {
     shift;
     goto &ExtUtils::MakeMaker::prompt;
 }
@@ -22,8 +24,19 @@ sub makemaker_args {
     $args;
 }
 
-sub build_subdirs {
+# For mm args that take multiple space-seperated args,
+# append an argument to the current list.
+sub makemaker_append {
     my $self = shift;
+    my $name = shift;
+    my $args = $self->makemaker_args;
+    $args->{name} = defined $args->{$name}
+    	? join( ' ', $args->{name}, @_ )
+    	: join( ' ', @_ );
+}
+
+sub build_subdirs {
+    my $self    = shift;
     my $subdirs = $self->makemaker_args->{DIR} ||= [];
     for my $subdir (@_) {
         push @$subdirs, $subdir;
@@ -31,17 +44,17 @@ sub build_subdirs {
 }
 
 sub clean_files {
-    my $self = shift;
+    my $self  = shift;
     my $clean = $self->makemaker_args->{clean} ||= {};
     %$clean = (
         %$clean, 
-        FILES => join(" ", grep length, $clean->{FILES}, @_),
+        FILES => join(' ', grep length, $clean->{FILES}, @_),
     );
 }
 
 sub libs {
     my $self = shift;
-    my $libs = ref $_[0] ? shift : [shift];
+    my $libs = ref $_[0] ? shift : [ shift ];
     $self->makemaker_args( LIBS => $libs );
 }
 
@@ -121,7 +134,7 @@ sub fix_up_makefile {
     local *MAKEFILE;
     open MAKEFILE, '< Makefile' or die $!;
     my $makefile = do { local $/; <MAKEFILE> };
-    close MAKEFILE;
+    close MAKEFILE or die $!;
 
     $makefile =~ s/\b(test_harness\(\$\(TEST_VERBOSE\), )/$1'inc', /;
     $makefile =~ s/( -I\$\(INST_ARCHLIB\))/ -Iinc$1/g;
@@ -131,8 +144,10 @@ sub fix_up_makefile {
     $makefile =~ s/^(PERL = .*)/$1 -Iinc/m;
 
     open MAKEFILE, '> Makefile' or die $!;
-    print MAKEFILE "$preamble$makefile$postamble";
-    close MAKEFILE;
+    print MAKEFILE "$preamble$makefile$postamble" or die $!;
+    close MAKEFILE or die $!;
+
+    1;
 }
 
 sub preamble {
@@ -143,7 +158,6 @@ sub preamble {
 
 sub postamble {
     my ($self, $text) = @_;
-
     $self->{postamble} ||= $self->admin->postamble;
     $self->{postamble} .= $text if defined $text;
     $self->{postamble}
@@ -157,11 +171,6 @@ __END__
 
 Module::Install::MakeMaker - Extension Rules for ExtUtils::MakeMaker
 
-=head1 VERSION
-
-This document describes version 0.01 of Module::Install::MakeMaker, released
-March 1, 2003.
-
 =head1 SYNOPSIS
 
 In your F<Makefile.PL>:
