@@ -1,7 +1,9 @@
 package Module::Install::Makefile::Name;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.01';
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
+$VERSION = '0.57';
 
 use strict;
 
@@ -10,7 +12,9 @@ sub determine_NAME {
     my @modules = glob('*.pm');
 
     require File::Find;
-    File::Find::find(sub { push @modules, $File::Find::name if /\.pm/i }, 'lib');
+    File::Find::find( sub {
+        push @modules, $File::Find::name if /\.pm/i;
+    }, 'lib');
 
     if (@modules == 1) {
         local *MODULE;
@@ -24,10 +28,10 @@ sub determine_NAME {
 
     return if $self->module_name;
 
-    my $name = MM->guess_name or die <<"END";
+    my $name = MM->guess_name or die <<"END_MESSAGE";
 Can't determine a NAME for this distribution.
 Please use the 'name' function in Makefile.PL.
-END
+END_MESSAGE
 
     $name =~ s/-/::/g;
     $self->module_name($name);
