@@ -3,7 +3,7 @@ package Module::Install::Metadata;
 use Module::Install::Base;
 @ISA = qw{Module::Install::Base};
 
-$VERSION = '0.06';
+$VERSION = '0.57';
 
 use strict 'vars';
 
@@ -59,6 +59,16 @@ sub sign {
     return $self;
 }
 
+sub dynamic_config {
+	my $self = shift;
+	unless ( @_ ) {
+		warn "You MUST provide an explicit true/false value to dynamic_config, skipping\n";
+		return $self;
+	}
+	$self->{'values'}{'dynamic_config'} = $_[0] ? 1 : 0;
+	return $self;
+}
+
 sub all_from {
     my ( $self, $file ) = @_;
 
@@ -127,8 +137,7 @@ sub feature {
         # The user used ->feature like ->features by passing in the second
         # argument as a reference.  Accomodate for that.
         $mods = $_[0];
-    }
-    else {
+    } else {
         $mods = \@_;
     }
 
