@@ -3,29 +3,32 @@ package Module::Install::Share;
 use Module::Install::Base;
 @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.01';
+$VERSION = '0.57';
 
 use strict;
 
 sub install_share {
-    my $self = shift;
-    my $dir  = shift;
+    my ($self, $dir) = @_;
 
     if ( ! defined $dir ) {
         die "Cannot find the 'share' directory" unless -d 'share';
         $dir = 'share';
     }
 
-    $self->postamble(<<".");
+    $self->postamble(<<"END_MAKEFILE");
 config ::
 \t\$(NOECHO) \$(MOD_INSTALL) \\
-\t\t\"$dir\" \$(INST_ARCHAUTODIR)
+\t\t\"$dir\" \$(INST_AUTODIR)
 
-.
+END_MAKEFILE
 }
 
+1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 Module::Install::Share - Install non-code files for use during runtime
@@ -44,11 +47,11 @@ As well as Perl modules and Perl binary applications, some distributions
 need to install read-only data files to a location on the file system
 for use at run-time.
 
-XML Schemas, YAML data files, and SQLite databases are examples of the
-sort of things distributions might typically need to have available
+XML Schemas, L<YAML> data files, and L<SQLite> databases are examples of
+the sort of things distributions might typically need to have available
 after installation.
 
-Module::Install::Share is a L<Module::Install> extension that provides
+C<Module::Install::Share> is a L<Module::Install> extension that provides
 commands to allow these files to be installed to the applicable location
 on disk.
 
