@@ -1,7 +1,9 @@
 package Module::Install::Win32;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.02';
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
+$VERSION = '0.57';
 
 use strict;
 
